/** *****************************************************
 * Copyright (C) HRider in motion S.L.
 *
 * This file is part of HRider.
 *
 * HRider can not be copied and/or distributed without the express
 * permission of HRider in motion S.L.
 ****************************************************** */
package net.hrider.api.usecases;

import java.util.logging.Logger;
import net.hrider.api.client.ApiException;
import net.hrider.api.model.Employee;
import net.hrider.api.model.EmployeesCollection;
import net.hrider.api.model.Link;

/**
 * Example to create, update and delete and employee.
 * 
 * @author drh (dani@hrider.net)
 */
public class CRUDEmployees extends AbstractUseCase {
    
    private static final Logger LOG = Logger.getLogger(CRUDEmployees.class.getName());

    @Override
    public void doRun() throws ApiException {               
        // create employees 
        Link employeesLink = getDummyCompany().getLinks().getEmployees();
        Employee emp1 = service.create(employeesLink, buildEmployee("EMP1", "Employee 1", "emp1@acme.com"));
        service.create(employeesLink, buildEmployee("EMP2", "Employee 2", "emp2@acme.com"));
        service.create(employeesLink, buildEmployee("EMP3", "Employee 3", "emp2@acme.com"));        

        // update employee 1
        emp1.setCode("NEW");
        service.put(emp1.getLinks().getSelf(), emp1);
        
        // get and print employees
        EmployeesCollection collection = service.get(EmployeesCollection.class, 
                getDummyCompany().getLinks().getEmployees());
        printEmployees(collection.getEmbedded().getEmployees());
        
        // delete employee and print
        service.delete(emp1.getLinks().getSelf());
        collection = service.get(EmployeesCollection.class, getDummyCompany().getLinks().getEmployees());
        printEmployees(collection.getEmbedded().getEmployees());
    }

    public static void main(String[] args) {
        (new CRUDEmployees()).run();
    }
    
}
